From 07fc650c7c9592976e901b274e36905810d9fe3d Mon Sep 17 00:00:00 2001
From: Alexander van Amesfoort <amesfoort@astron.nl>
Date: Sat, 31 Mar 2012 23:14:29 +0000
Subject: [PATCH] Task #3185: RTCP/Storage: MSWriter LDA to DAL, prep TBB
 Writer w/ DAL.

LDA and DAL includes don't co-exist well.
---
 .gitattributes                                |  6 +++---
 RTCP/Storage/CMakeLists.txt                   |  2 +-
 .../Storage/{MSWriterLDA.h => MSWriterDAL.h}  | 10 +++++-----
 RTCP/Storage/src/CMakeLists.txt               |  2 +-
 .../src/{MSWriterLDA.cc => MSWriterDAL.cc}    | 20 +++++++++----------
 RTCP/Storage/src/OutputThread.cc              |  4 ++--
 RTCP/Storage/test/CMakeLists.txt              |  2 +-
 RTCP/Storage/test/{tLDA.cc => tDAL.cc}        | 12 +++++------
 8 files changed, 29 insertions(+), 29 deletions(-)
 rename RTCP/Storage/include/Storage/{MSWriterLDA.h => MSWriterDAL.h} (88%)
 rename RTCP/Storage/src/{MSWriterLDA.cc => MSWriterDAL.cc} (96%)
 rename RTCP/Storage/test/{tLDA.cc => tDAL.cc} (82%)

diff --git a/.gitattributes b/.gitattributes
index b12b766e94c..087879b99ec 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -2636,22 +2636,22 @@ RTCP/Storage/include/Storage/FastFileStream.h -text
 RTCP/Storage/include/Storage/Format.h -text
 RTCP/Storage/include/Storage/HDF5Attributes.h -text
 RTCP/Storage/include/Storage/IOPriority.h -text
+RTCP/Storage/include/Storage/MSWriterDAL.h -text
 RTCP/Storage/include/Storage/MSWriterFile.h -text
-RTCP/Storage/include/Storage/MSWriterLDA.h -text
 RTCP/Storage/include/Storage/MSWriterNull.h -text
 RTCP/Storage/include/Storage/MeasurementSetFormat.h -text
 RTCP/Storage/include/Storage/OutputThread.h -text
 RTCP/Storage/src/FastFileStream.cc -text
 RTCP/Storage/src/Format.cc -text
+RTCP/Storage/src/MSWriterDAL.cc -text
 RTCP/Storage/src/MSWriterFile.cc -text
-RTCP/Storage/src/MSWriterLDA.cc -text
 RTCP/Storage/src/MSWriterNull.cc -text
 RTCP/Storage/src/MeasurementSetFormat.cc -text
 RTCP/Storage/src/OutputThread.cc -text
 RTCP/Storage/src/gnuplotMS.sh -text
 RTCP/Storage/src/plotMS.cc -text
+RTCP/Storage/test/tDAL.cc -text
 RTCP/Storage/test/tFastFileStream.cc -text
-RTCP/Storage/test/tLDA.cc -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-j2000 -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-sun -text
 SAS/Beaminfo/CMakeLists.txt -text
diff --git a/RTCP/Storage/CMakeLists.txt b/RTCP/Storage/CMakeLists.txt
index e21bbd5e5b1..4388dc440aa 100644
--- a/RTCP/Storage/CMakeLists.txt
+++ b/RTCP/Storage/CMakeLists.txt
@@ -4,7 +4,7 @@ lofar_package(Storage 1.0 DEPENDS Common ApplCommon Interface MSLofar LofarStMan
 
 include(LofarFindPackage)
 lofar_find_package(Casacore COMPONENTS casa measures ms tables REQUIRED)
-lofar_find_package(LDA REQUIRED)
+lofar_find_package(DAL REQUIRED)
 lofar_find_package(HDF5 REQUIRED)
 
 add_subdirectory(include/Storage)
diff --git a/RTCP/Storage/include/Storage/MSWriterLDA.h b/RTCP/Storage/include/Storage/MSWriterDAL.h
similarity index 88%
rename from RTCP/Storage/include/Storage/MSWriterLDA.h
rename to RTCP/Storage/include/Storage/MSWriterDAL.h
index 3e5f2a56cbf..6b32a1ecd6b 100644
--- a/RTCP/Storage/include/Storage/MSWriterLDA.h
+++ b/RTCP/Storage/include/Storage/MSWriterDAL.h
@@ -23,8 +23,8 @@
 //////////////////////////////////////////////////////////////////////
 
 
-#ifndef LOFAR_STORAGE_MSWRITERLDA_H
-#define LOFAR_STORAGE_MSWRITERLDA_H
+#ifndef LOFAR_STORAGE_MSWRITERDAL_H
+#define LOFAR_STORAGE_MSWRITERDAL_H
 
 //# Includes
 #include <Common/LofarTypes.h>
@@ -42,11 +42,11 @@ namespace LOFAR
 
   namespace RTCP
   {
-    template<typename T, unsigned DIM> class MSWriterLDA : public MSWriterFile
+    template<typename T, unsigned DIM> class MSWriterDAL : public MSWriterFile
     {
     public:
-      MSWriterLDA(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
-      ~MSWriterLDA();
+      MSWriterDAL(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
+      ~MSWriterDAL();
       virtual void write(StreamableData *data);
     private:
       const Transpose2 &itsTransposeLogic;
diff --git a/RTCP/Storage/src/CMakeLists.txt b/RTCP/Storage/src/CMakeLists.txt
index 1391854dd9d..b3b4ea4b979 100644
--- a/RTCP/Storage/src/CMakeLists.txt
+++ b/RTCP/Storage/src/CMakeLists.txt
@@ -9,7 +9,7 @@ lofar_add_library(storage
   OutputThread.cc
   SubbandWriter.cc
   MSWriter.cc
-  MSWriterLDA.cc
+  MSWriterDAL.cc
   MSWriterNull.cc
   MSWriterFile.cc
   Format.cc
diff --git a/RTCP/Storage/src/OutputThread.cc b/RTCP/Storage/src/OutputThread.cc
index 73de63beca2..ddefbccbef7 100644
--- a/RTCP/Storage/src/OutputThread.cc
+++ b/RTCP/Storage/src/OutputThread.cc
@@ -25,7 +25,7 @@
 
 #include <Common/StringUtil.h>
 #include <Storage/MSWriterFile.h>
-#include <Storage/MSWriterLDA.h>
+#include <Storage/MSWriterDAL.h>
 #include <Storage/MSWriterNull.h>
 #include <Storage/MeasurementSetFormat.h>
 #include <Storage/OutputThread.h>
@@ -159,7 +159,7 @@ void OutputThread::createMS()
     // HDF5 writer requested
     switch (itsOutputType) {
       case BEAM_FORMED_DATA:
-        itsWriter = new MSWriterLDA<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
+        itsWriter = new MSWriterDAL<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
         break;
       default:
         itsWriter = new MSWriterFile(path, itsOutputType == BEAM_FORMED_DATA);
diff --git a/RTCP/Storage/test/CMakeLists.txt b/RTCP/Storage/test/CMakeLists.txt
index 00a59edf1ca..77d72bbd126 100644
--- a/RTCP/Storage/test/CMakeLists.txt
+++ b/RTCP/Storage/test/CMakeLists.txt
@@ -3,6 +3,6 @@
 include(LofarCTest)
 
 lofar_add_test(tMeasurementSetFormat tMeasurementSetFormat.cc)
-lofar_add_test(tLDA tLDA.cc)
+lofar_add_test(tDAL tDAL.cc)
 lofar_add_test(tFastFileStream tFastFileStream.cc)
 #lofar_add_test(tAH_TestStorage tAH_TestStorage.cc)
diff --git a/RTCP/Storage/test/tLDA.cc b/RTCP/Storage/test/tDAL.cc
similarity index 82%
rename from RTCP/Storage/test/tLDA.cc
rename to RTCP/Storage/test/tDAL.cc
index b3a36ddf60b..a687b6dd96c 100644
--- a/RTCP/Storage/test/tLDA.cc
+++ b/RTCP/Storage/test/tDAL.cc
@@ -1,6 +1,6 @@
-//# tHDF5: Test HDF5 routines
+//# tDAL: Test HDF5 routines through DAL
 //#
-//#  Copyright (C) 2001
+//#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
 //#  P.O.Box 2, 7990 AA Dwingeloo, The Netherlands, seg@astron.nl
 //#
@@ -22,18 +22,18 @@
 
 #include <lofar_config.h>
 
-#ifdef HAVE_LDA
+#ifdef HAVE_DAL
 
-#include <lda_version.h>
+#include <dal_version.h>
 #include <iostream>
 #include <string>
 
 using namespace std;
-using namespace LDA;
+using namespace DAL;
 
 int main() {
   if (!check_hdf5_versions()) {
-    cerr << "HDF5 version mismatch. LDA was compiled with " << get_lda_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
+    cerr << "HDF5 version mismatch. DAL was compiled with " << get_dal_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
     return 1;
   }
   
diff --git a/RTCP/Storage/src/MSWriterLDA.cc b/RTCP/Storage/src/MSWriterDAL.cc
similarity index 96%
rename from RTCP/Storage/src/MSWriterLDA.cc
rename to RTCP/Storage/src/MSWriterDAL.cc
index 30a690f8047..9a1cb2c04a4 100644
--- a/RTCP/Storage/src/MSWriterLDA.cc
+++ b/RTCP/Storage/src/MSWriterDAL.cc
@@ -1,6 +1,6 @@
 //# MSWriterLDA: an implementation of MSWriter using the LDA to write HDF5
 //#
-//#  Copyright (C) 2001
+//#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
 //#  P.O.Box 2, 7990 AA Dwingeloo, The Netherlands, seg@astron.nl
 //#
@@ -26,11 +26,11 @@
 #include <Common/SystemUtil.h>
 
 #include <Storage/MSWriter.h>
-#include <Storage/MSWriterLDA.h>
+#include <Storage/MSWriterDAL.h>
 
 #include <lofar/BF_File.h>
 
-using namespace LDA;
+using namespace DAL;
 using namespace std;
 
 #include <Common/Thread/Mutex.h>
@@ -101,7 +101,7 @@ namespace LOFAR
     // uses global locks too anyway.
     static Mutex HDF5Mutex;
 
-    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::MSWriterLDA (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
+    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::MSWriterDAL (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
     :
       MSWriterFile(forceextension(string(filename),".raw"),false),
       itsTransposeLogic(parset.transposeLogic()),
@@ -157,11 +157,11 @@ namespace LOFAR
           break;
 
         case INVALID_STOKES:
-          LOG_ERROR("MSWriterLDA asked to write INVALID_STOKES");
+          LOG_ERROR("MSWriterDAL asked to write INVALID_STOKES");
           return;
       }    
 
-      LOG_DEBUG_STR("MSWriterLDA: opening " << filename);
+      LOG_DEBUG_STR("MSWriterDAL: opening " << filename);
 
       // create the top structure
       BF_File file(h5filename, BF_File::CREATE);
@@ -408,11 +408,11 @@ namespace LOFAR
       stokesDS.nofSamples()     .set(dims[0]);
     }
 
-    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::~MSWriterLDA()
+    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::~MSWriterDAL()
     {
     }
 
-    template <typename T,unsigned DIM> void MSWriterLDA<T,DIM>::write(StreamableData *data)
+    template <typename T,unsigned DIM> void MSWriterDAL<T,DIM>::write(StreamableData *data)
     {
       SampleData<T,DIM> *sdata = dynamic_cast<SampleData<T,DIM> *>(data);
 
@@ -434,7 +434,7 @@ namespace LOFAR
     }
 
     // specialisation for FinalBeamFormedData
-    template class MSWriterLDA<float,3>;
+    template class MSWriterDAL<float,3>;
 
   } // namespace RTCP
 } // namespace LOFAR
@@ -1,6 +1,6 @@
-//# MSWriterLDA: an implementation of MSWriter using the LDA to write HDF5
+//# MSWriterDAL: an implementation of MSWriter using the DAL to write HDF5
 //#
-- 
GitLab